from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x07\x00\x42\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\x87\x08\x00\x00\x00\x00\x00\x18\x82\x97\xc4\xa1\x03\xad\xc9\x0b\x83\x37\x21\xd8\xd2\x37\xb0\x45\x00\x00\x00\x00\x00\x00\x00\x00\xcf\x3e\x8e\x33\xbf\xbb\x06\xd0\x2f\x89\x85\x24\xc4\x2a\x97\x8e\xda\x4a\xff\xd9\x5b\xe8\x49\x7d\x9c\xd9\x12\x06\x85\xa7\xed\x11\x55\xa8\xbb\xb7\x75\xc0\xa5\x43\x83\x98\x00\xea\x8b\x3b\x2d\xe7\x40\xb6\x58\x7b\xde\xaf\xc7\x19\x45\x90\x26\x93\xa4\x95\x0c\xa5\x0b\x80\x55\x75\x78\x80\xf0\x53\xa1\xf9\x40\xd0\x10\x48\x85\x79\x0f\xb6\x9a\x58\x83\xcd\x11\xa3\x6f\x2a\x6b\xce\xc4\x30\x63\x07\x29\xc3\xf0\xa7\xd7\x17\x94\x29\xa9\x7e\xd0\x1b\x2e\x88\xba\xb2\xf1\x31\x46\xce\xad\x79\xe6\x4a\x50\x11\x63\x8f\xb1\xdf\x50\xf3\x35\x08\x71\xf4\x2d\xba\x45\x9c\xe1\xee\x6e\xd2\x10\xcd\x32\x92\x86\x63\x33\x8a\x62\x4d\x4a\xe5\x25\x93\x74\x04\x8b\x57\x40\x6a\xd8\x59\x97\xad\xaa\x31\x59\xab\x9e\xde\x5a\x35\x91\x7d\x5d\x0e\x4c\xe6\x17\x3e\x37\xf8\xd1\xc4\xf2\x72\xb6\x6d\x5b\x77\xe7\x6c\xe6\x36\x16\x1a\x0e\xec\x91\xb0\x72\xcf\x5a\x29\x70\x19\x49\x75\x73\x51\x69\x42\xf3\x34\xe2\x2f\x59\xc8\x92\x60\x4f\x2b\x65\xf3\x36\x6b\xf5\xd2\xd3\xe0\x3e\x7d\xbc\x72\xea\xf5\xd2\xf6\x0e\x63\x61\x0b\x3a\x74\x54\x19\x43\x37\xe4\x59\xb0\xa7\x61\x7b\xec\x58\xbd\xb7\x58\x1c\x01\x3d\xda\x11\x28\xd3\xe8\x70\x3b\x89\xd7\xd2\x3c\x6f\x94\x77\x56\xee\x6e\x90\xc4\x73\xd8\xda\x10\x29\x54\xde\xdd\x0c\x65\x31\xb1\x83\x04\x3c\x39\x51\x60\x0f\xb8\x84\x6a\xc4\xfd\xdb\x83\x2e\xea\xba\x07\x8e\x27\x48\x7c\x04\xce\x82\x2f\x7c\xee\xa9\x63\x6c\x36\xc3\xf9\x61\xa1\x20\x1f\x1c\xc5\x47\xb9\x0c\xc6\x48\x84\x55\xe1\xe8\x3c\x83\x94\x0e\xdc\xa9\x44\x66\xb5\xac\x3b\x6f\xbf\x7f\x83\x3f\xfb\x5d\x40\xb0\x5a\x64\x59\x90\xd0\x03\x31\x9f\x96\xba\x11\x8b\xc7\x5a\x00\x82\x36\xc1\x96\x67\x85\xb6\x88\x87\x60\x78\xa2\x55\xae\x85\xcc\xc1\x16\x13\xab\x76\x69\xb7\x65\x34\x06\x37\x7c\xa0\x27\x78\x97\x08\x77\x5a\xc3\x79\x3a\x10\x80\x1d\xb2\xf3\x4c\xaf\x64\x4e\xfa\x14\x29\xe0\xe5\xcc\x22\x45\x53\x0e\x49\x74\x4a\xa0\x77\x34\xf0\x50\xcd\x4f\x4f\x64\x82\x32\x92\xbf\xde\xed\x7c\x25\x5b\x68\xe0\x7f\x92\x92\xb4\x70\xaf\xcb\xd6\x96\x9f\xbb\x21\xba\x1a\x2b\xf2\x61\x46\x85\x7d\x4b\x12\x74\x29\x69\x02\x23\xa2\x0f\x19\xd6\x6d\x73\x60\xa3\x48\xbc\x36\xe5\x6a\x1e\x23\xf0\xf7\x02\x2e\x3f\x8b\x87\xe3\x4c\xb0\x0d\x15\x49\x8b\x15\x96\x5e\x98\x6d\xe4\xa2\x7a\xe6\xba\x66\x77\xa7\x2f\xc0\xd8\x6a\x74\x27\x52\x30\x19\x66\x96\xe6\x41\x59\xfc\x0a\x9d\xcc\x48\x6f\xf9\x12\xec\x19\x8a\x5f\xae\x5b\xee\x18\x96\xf3\x58\xe8\x36\xe4\xb7\x05\xdd\xc0\x47\xfe\x9f\xb9\xd3\x9d\xdc\x65\xde\xf4\xa6\x49\xa6\xcd\xc7\x1c\xc5\x5f\x30\xdf\xc5\xc3\x32\xe1\x43\xa9\xd4\xb7\xa9\xaa\x89\xbe\x3d\xc2\x94\xef\x28\x22\xa8\xbf\xbd\xf9\x88\xd1\x27\x22\x11\x7b\x88\x2d\x7f\x00\x8d\x83\x39\xc4\x06\x14\x37\x2f\xe1\x33\x32\x4a\xbe\x5f\x82\x3d\x35\x1d\xd7\x79\x24\x43\x51\x9d\xea\xb0\xa6\x57\x45\x6b\x63\xb9\x91\x2d\x79\xd3\xff\x3f\xf6\xaa\xc5\xdb\x2c\x2d\x86\x83\x6b\xf2\x49\xdf\x68\x2e\xe1\x00\xde\xba\x6c\x5c\x36\x17\xd5\xdb\x31\x91\xaf\x8f\x15\x7a\xc5\x06\x72\x24\x3f\x38\x1d\x59\x70\x2f\xb3\x3b\x65\x1f\x94\xca\x3f\x8d\xf0\xc8\x89\xfb\x53\x16\x61\xad\x88\x9c\x34\xcd\xe1\x9d\xb6\x32\x6b\x3b\x45\x85\x62\xb1\x67\xbd\xb8\xd4\xa0\x21\xb1\xb4\xd3\x94\x98\x2b\xda\x61\x83\xec\x28\x25\xb2\xe5\x5a\x0e\x3d\x65\xf3\xfe\x4f\xba\x74\x9a\xbf\xbd\xed\x0f\xf0\x84\x77\x7b\xe0\x82\x4a\x66\xcd\x0e\x3b\x3a\xc7\x57\xc1\x9d\xe5\xa6\xf4\x00\xbe\x4a\x22\x25\xc8\x27\x0d\x9d\xb6\x7c\xe6\x46\x3e\x4e\x3f\x10\x5b\x7d\x6a\x2e\xb5\xd2\x2a\x94\xf5\xdb\x08\x34\x14\x83\x88\xc0\x4d\x35\xc3\xb6\x02\x28\x5f\xba\x8b\x1a\x8d\xaf\x18\xac\x3b\xee\x71\xbf\xa2\x0d\xac\x1e\xcd\x8d\x90\x4e\xd6\xc7\xd9\x41\xb0\xdc\x1a\x5f\x02\x51\xea\x0f\x5e\x18\x4d\x1d\x5e\x18\xd1\xcd\x80\x15\x88\x49\x47\xef\xbf\x6c\x13\x13\x70\x2e\x46\xbd\xae\xb2\x94\xbe\xe8\xad\x7d\x77\xad\x38\x2f\x11\xcb\xc5\xbe\xf8\x41\x8c\x13\xf1\x13\x18\x24\xe2\x8f\x07\x50\xcc\x0e\xfa\x2f\xb0\x07\x9d\xe3\x42\xef\x76\xac\xfc\xa4\xc5\xd4\xaf\x85\x2e\x1b\x09\x82\x6e\x83\xe2\x09\xb2\x6c\xdb\x8d\x6f\x40\x8c\xdd\xc1\x1a\x05\xfc\x8d\xcc\x12\xf0\x0d\x9a\x4b\xae\x75\x6e\x42\x24\xc5\x9c\xb9\xf1\x94\x8c\x94\x19\x2e\xb4\x41\x6c\xe3\xd8\xa2\x71\xe0\x3b\x5b\x28\x53\x7a\x28\x27\xb1\x3e\xd4\xeb\x11\xa2\x90\xe6\x0d\xcb\x51\xf2\xcd\x61\x46\x7e\x52\x45\x7f\xd7\x26\xd3\x5a\x57\x90\xb7\xc5\x94\x07\x51\x81\x1f\x3c\xc2\x4f\x3f\x2f\xbc\xb1\xca\x9b\xac\x94\x31\x4b\xf4\x1e\x70\xc0\x7d\x93\x14\x48\x1f\x2d\xca\xae\x20\x03\x75\x07\x26\x82\xc4\xe3\xc6\x90\xf1\x2a\x38\x46\xd8\x90\x90\x60\x6c\x6c\x43\x51\xa9\x08\x28\x96\x47\x0a\xe4\xb3\x19\x63\xc4\x9a\x47\xa2\xc1\xe3\x27\xc4\x48\x7d\x3f\xea\xd9\x5f\x3d\xbe\x59\xa1\xd4\x05\xcb\xb6\x97\x2e\xbd\xbd\x4c\xa6\x62\x41\x9a\xaf\xff\xf5\x8b\x4d\x31\xa1\x14\x4a\x65\x0d\xa3\xd9\x2c\xc5\x9e\x36\x4b\xca\x97\x2c\xed\xda\x08\x4a\x72\xf7\x04\x24\x06\x51\x14\xd7\x5f\x20\xac\x96\xd4\xcd\xf1\xf6\xaa\x5d\xbf\x52\xb8\x60\x77\x81\x4c\x2b\xb4\xf0\xdf\x97\x02\x09\x49\xc2\x73\x55\x32\x18\x4e\x69\x61\xbf\x1d\x37\x87\xa6\x95\xcb\xe9\x2a\x2d\xc4\xf2\xcf\x6f\x58\xbe\x3b\x02\x52\x64\x37\x51\xe3\x6e\x6d\x8c\xbd\x45\xa7\xed\x2f\x33\x4f\x7b\xd3\x34\x5c\x1b\x9a\xf4\xe8\x3a\x26\x5c\xcd\x68\x38\xb0\x45\xe6\x0b\x70\x4c\xd8\xcb\xb6\xc3\x80\xbb\x92\x17\xa4\x7a\x8a\x98\xf2\xc6\x45\x47\xfc\x6d\xd6\xb8\x38\xfd\x05\xf3\x35\xc7\xb4\x04\xa3\xd7\xd3\x80\x40\x23\x3f\x07\x1f\x84\xb7\x38\x17\xcb\x5f\x85\xad\xdf\xcc\x8b\xd1\x21\xba\x1c\x22\xe7\x0d\xce\x88\x66\x2e\xee\xfb\x83\x8e\xeb\x32\x88\x3b\x83\xca\x02\x5d\xe5\x64\x22\x5d\xa1\x1f\x70\xc0\x03\x80\x6a\x06\x55\x1c\x1d\xe6\x5a\x5f\xbb\x65\xa3\x47\x8c\x60\x5e\xf3\xa2\x35\x4a\xf6\x6e\x24\x8d\xd7\x98\xef\x09\x03\x91\x41\x95\x8d\x6c\x19\x6b\x04\xa9\x0d\x6f\x92\x91\x42\x0d\xc3\xb2\xe7\x2e\xe1\x98\xb1\x7b\xb3\xaa\x1c\x45\x82\x5c\x5e\x5a\x5e\xfa\xc7\x9e\x3b\x01\x5f\xb3\x31\x7f\x02\x9c\x76\x7b\xcc\xcd\x20\x3b\x75\xb2\x3f\x5a\x3a\x29\xc5\xe7\xec\xca\xb5\xdd\xa1\xeb\x22\x67\x29\x9e\x66\x77\x28\xb6\x1c\x64\x0d\x71\x1e\x8a\xbe\x69\x21\x8b\xb4\xe5\xa0\x28\xa8\x1b\x89\xbe\x9c\x49\xa6\x90\xe1\xaa\xda\xe0\xbc\x85\x87\xe5\xc0\x56\x43\x7b\xd2\xdb\xdb\x87\x83\x22\x85\x61\x94\xd4\xa5\x58\x79\x28\x44\x56\xa7\xe4\xc6\xb2\xee\xb1\x77\x3c\x47\x52\x50\x5f\x5b\x2e\x1d\x72\xaf\x64\x9a\x7b\x86\x88\x26\x65\xe6\xe8\xb8\x69\x2c\xf4\x8d\x1a\xa3\xc6\x79\x1d\xf2\x10\xc7\x3c\xe1\x5c\xf6\x01\x88\xc0\x35\xb4\xbd\x95\x39\x21\x94\xa1\x61\xe0\xff\x8e\xaf\xb8\x06\xcb\x4a\x5f\x2d\x25\xbe\x03\xc4\xbc\xec\x7b\xd2\x01\x4d\xa8\x8b\xd2\x9d\xef\x44\x34\xc5\xfe\x0e\xaf\x46\x9d\xd6\xf3\x87\x8f\x95\x94\x2f\xfa\x9d\x4b\x3b\xb4\xd1\x50\x52\x16\x35\x7d\x74\xb5\xdc\x65\x77\xe1\x5f\xbd\xcd\xcb\x19\x51\x06\xb3\xf8\xbd\xff\x65\x54\x7f\x2f\x24\x66\x03\xa9\x87\xcc\xa1\x1f\x73\xa4\x5d\x60\x3c\x9d\xad\x98\x12\x2c\xc0\x05\x5b\xc0\x16\xe0\xb8\xb2\xdc\x87\x24\xb8\x5a\x4e\x33\x92\x2b\xa0\x94\xe7\x00\x4d\x0c\x75\x45\xe8\x11\xfd\x71\xcf\x24\xee\x59\xff\x50\x41\x63\xcf\x91\x91\x0f\x7d\x5c\xd9\xb4\x43\xaa\x7c\xb0\xd3\x27\xc3\xde\x1c\x93\xd2\xf9\x06\x53\x45\x2b\xae\xb1\x54\xc9\x9b\xfb\x87\x17\x23\x2e\xb6\xce\xa7\x6d\xae\xbf\x62\x76\xce\xc8\x31\x04\x1c\x2c\x20\x2e\x20\xf6\x62\xa3\x9d\x63\x2c\x4d\x06\x21\x1a\xae\x34\xcc\xc4\x3f\x8f\x1e\xf3\x9e\xb5\x88\x5e\x97\xe7\x77\xea\x5c\x42\xd5\x1a\xa7\x2f\xad\xe5\x52\xdc\x70\xe0\xf2\x67\x76\xeb\x0b\xdf\xb3\xf9\xa9\xc7\x5d\xf2\x86\x42\xb3\x43\xb7\xc8\xc7\x98\xdb\x0f\x68\xf6\x91\x19\xf7\xa9\x4b\x15\xa7\x47\xfb\xb7\xca\xc7\xab\xb5\x68\x0d\x17\x12\x09\x4f\xcb\xd9\x55\xb0\x12\x25\x39\xf1\x58\x71\x57\x02\xb2\xf5\xc1\x87\xc3\xde\xf8\x9c\xd0\x70\x9a\x32\xe5\xf0\xce\xb8\x70\xe9\xa6\x57\x82\x80\xc1\x1a\xc9\xef\x2e\xd9\x3d\x08\xa9\x47\x23\xd3\xb1\xfa\xe5\x2c\x7e\x68\x94\xa8\xcc\x4e\x81\x32\x64\x10\xbd\x9e\x87\x3f\xf7\xb8\x79\xfc\xd8\xd2\x0c\xaa\x6b\x96\x8f\x50\x8b\x8c\xfc\xc6\x0f\xa1\xd2\x09\xfb\x30\xbd\x02\x16\x12\xc7\x97\x21\xd9\x1c\x33\xb4\x49\x9f\x59\x44\x7f\x85\x25\x22\xf5\x73\x9b\xd2\x38\x31\x3f\xc8\xb0\xda\x38\x2b\xf3\x5d\x48\xa1\x98\x07\x88\x06\x2d\xd8\x52\xa2\xb2\xc1\x89\x24\x54\xfa\xd7\x32\x75\xc3\x38\x6c\xed\x12\xca\xbd\xa0\xba\x34\xa6\xde\xec\x35\x79\xe7\xa7\x14\x6f\xc6\x16\x56\x22\x3a\x5b\xa8\x22\xe6\xd6\x32\x25\x3d\xef\x5f\x4c\x53\xc7\xc5\x0a\xfd\x1a\xa0\xc5\x7b\xda\x69\x25\xb8\xe6\x42\x91\x3c\x1c\xd2\xfc\x5c\x4d\x56\x41\x95\xff\xbd\x45\x7a\x05\x61\x5a\xe2\xae\xaf\x5d\x1f\x1d\x87\x22\x2c\x79\xc9\xcd\x9d\x63\x24\x12\xe2\x7a\x98\x83\x84\x36\x15\xf9\xc1\xbb\xcf\x05\xfb\x58\xd2\x28\x0c\x04\xf3\x20\x27\x21\x1f\xb5\xfa\x92\xad\xd4\x7a\x04\x06\xff\x48\xd4\x5e\xe2\x50\x96\x90\x08\xfc\xa7\xb0\x18\x8f\xc5\xa1\xaa\xca\xaf\xea\x14\x47\xcb\x95\x9d\x21\x63\x6f\xf6\x88\x5c\x7f\xad\x42\x16\xb0\xa6\x11\xd9\x14\xb3\x67\xab\xd4\x3f\x55\x1a\xa2\x17\x41\x18\xfb\x75\x13\x7b\x97\xe5\xa3\x12\x1c\xf3\x59\x17\x29\xd9\x78\xeb\x84\x6d\x51\xa7\x6f\x6f\x97\x0b\x31\x14\x85\x34\x3d\xa9\x04\x71\xf7\xf2\x0b\x61\xe6\x25\x40\xae\xd1\xb1\xb9\x94\x3c\xcd\x08\x1b\x0e\x07\x27\xae\x56\xc1\x44\x9f\xe0\x07\xa1\x5d\xb6\xc5\xb7\x52\x24\x97\x73\x23\x84\x41\xb5\x11\xee\x97\xdd\x27\x56\xd0\xdb\xbd\x1b\x77\xc3\x4f\x82\x27\x0f\x8f\x81\xc8\x2f\x21\x86\xf0\xc2\xc2\xa7\xb5\xbb\x30\x1e\x6e\xd4\x2c\xce\x62\xf9\x98\xb4\xe1\xc5\x9a\x28\x2b\x1c\xd8\x1f\x05\x8c\x15\xa1\x56\xdf', 2)

# cleanup
del pyarmor_runtime

